.. :changelog:

History
-------

0.5.0 (2016-04-14)

* Added TravisCI badge in README.rst
* Added download_url in setup.py

0.4.0 (2016-04-14)

* Remove PassThroughManagerMixin

0.1.0 (2015-10-02)
++++++++++++++++++

* First release on PyPI.
